==> nextcloud-app-notes-3.4.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/gl.js <==
OC.L10N.register(
    "notes",
    {
    "Notes" : "Notas",
    "The last viewed note cannot be accessed. " : "Non é posíbel acceder á última nota vista. ",
    "The notes folder is not accessible: %s" : "Non é posíbel acceder ao cartafol de notas: %s",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Distraction-free notes and writing" : "Escritura de notas sen distraccións ",
    "The Notes app is a distraction free notes taking app for [Nextcloud](https://www.nextcloud.com/). It provides categories for better organization and supports formatting using [Markdown](https://en.wikipedia.org/wiki/Markdown) syntax. Notes are saved as files in your Nextcloud, so you can view and edit them with every Nextcloud client. Furthermore, a separate [REST API](docs/api/README.md) allows for an easy integration into third-party apps (currently, there are notes apps for [Android](https://github.com/stefan-niedermann/nextcloud-notes), [iOS](https://github.com/owncloud/notes-iOS-App) and the [console](https://git.danielmoch.com/nncli/about) which allow convenient access to your Nextcloud notes). Further features include marking notes as favorites." : "A aplicación Notas é unha aplicación que toma notas sen distracción para [Nextcloud] (https://www.nextcloud.com/). Fornece categorías para unha mellor organización e admite o formato coa sintaxe [Markdown](https://es.wikipedia.org/wiki/Markdown). As notas gárdanse como ficheiros no Nextcloud, polo que pode velas e editalas con calquera cliente Nextcloud. Ademais, unha [REST API](docs/api/README.md) separada permite unha fácil integración en aplicacións de terceiros (actualmente hai aplicacións de notas para [Android](https://github.com/stefan-niedermann/nextcloud-notes) [[iOS](https://github.com/owncloud/notes-iOS-App) and the [consola](https://git.danielmoch.com/nncli/about) que permiten un acceso cómodo ás súas notas do Nextcloud). Outras características inclúen marcar notas como favoritas.",
    "Settings" : "Axustes",
    "Deleted {title}" : "{title} foi eliminado",
    "Deleted {number} notes" : "Eliminadas {number} notas",
    "Undo Delete" : "Desfacer a eliminación",
    "Please chose a valid path in {label} (bottom left corner)." : "Escolla unha ruta válida en {label} (canto inferior esquerdo).",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hai notas sen gardar. Saír da páxina desbotará todos os cambios!",
    "Folder to store your notes" : "Cartafol para almacenar as súas notas",
    "path to notes" : "ruta ás notas",
    "File extension for new notes" : "Extensión do ficheiro para notas novas",
    "All notes" : "Todas as notas",
    "Categories" : "Categorías",
    "No search result for “{search}” in {category}" : "Sen resultados de busca para «{search}» en {category}",
    "No search result for “{search}”" : "Sen resultados de busca para «{search}»",
    "Loading …" : "Cargando…",
    "Search result for “{search}” in {category}" : "Resultados de busca para «{search}» en {category}",
    "Search result for “{search}”" : "Resultados de busca para «{search}»",
    "Today" : "Hoxe",
    "Yesterday" : "Onte",
    "This week" : "Esta semana",
    "Last week" : "A semana pasada",
    "This month" : "Este mes",
    "Last month" : "O mes pasado",
    "Rename" : "Renomear",
    "Note's title" : "Título da nota",
    "Delete note" : "Eliminar nota",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "Error during preparing note for deletion." : "Produciuse un erro ao preparar a nota para a eliminación.",
    "Empty note" : "Nota baleira",
    "Write …" : "Escribir…",
    "Details" : "Detalles",
    "Preview" : "Vista previa",
    "Edit" : "Editar",
    "Exit full screen" : "Saír da pantalla completa",
    "Full screen" : "Pantalla completa",
    "Save failed. Click to retry." : "Produciuse un fallo ao gardar. Prema para volver tentalo.",
    "Set category" : "Estabelecer a categoría",
    "Category" : "Categoría",
    "Uncategorized" : "Sen categorizar",
    "Click here to save manually" : "Prema aquí para gardar manualmente",
    "Saving failed!" : "Produciuse un fallo ao gardar!",
    "Last modified: {date}" : "Última modificación: {date}",
    "Note has unsaved changes" : "A nota contén cambios sen gardar",
    "Subcategory" : "Subcategoria",
    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
    "Write down your thoughts without any distractions." : "Anote os seus pensamentos sen distraccións.",
    "Use Markdown markups to style your text." : "Empregue o marcado de Markdown para o estilo do seu texto.",
    "Organize your notes in categories." : "Organice as súas notas en categorías.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instale a aplicación para o seu teléfono móbil para poder acceder ás súas notas en calquera lugar.",
    "Android app" : "Apli de Android",
    "iOS app" : "Apli de iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comece a escribir unha nota premendo en «{newnote}» na navegación da aplicación.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Pode crear subcategorías empregando «/» como delimitador entre a categoría principal e a subcategoría, por exemplo «{parent}/{sub}».",
    "See JavaScript console and server log for details." : "Vexa a consola de JavaScript e o rexistro do servidor para os detalles.",
    "Saving the note has failed due to insufficient storage." : "Produciuse un fallo ao almacenar a nota por mor de non haber espazo abondo.",
    "Updating settings has failed." : "Produciuse un fallo ao actualizar a configuración.",
    "Fetching notes has failed." : "Produciuse un fallo ao recuperar as notas.",
    "Fetching note {id} has failed." : "Produciuse un fallo ao recuperar a nota {id}.",
    "Renaming note {id} has failed." : "Produciuse un fallo ao renomear a nota {id}.",
    "Creating new note has failed." : "Produciuse un fallo ao crear a nova nota.",
    "Updating note {id} has failed." : "Produciuse un fallo ao actualizar a nota {id}.",
    "Undo delete has failed for note {title}." : "Produciuse un fallo ao desfacer a eliminación da nota {title}.",
    "Deleting note {id} has failed." : "Produciuse un fallo ao eliminar a nota {id}.",
    "Toggling favorite for note {id} has failed." : "Produciuse un fallo ao activar o favorito para a nota {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Produciuse un fallo ao actualizar a categoría da nota. Pódese escribir no directorio de destino?",
    "Updating the category for note {id} has failed." : "Produciuse un fallo ao actualizar a categoría da nota {id}.",
    "Development Mode" : "Modo desenvolvedor",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que a aplicación de notas foi instalada dende unha orix de desenvolvemento. Instálea dende a <a href=\"%1$s\">tenda oficial de aplicacións do Nextcloud</a> no seu lugar. Se quere construír a aplicación Notes por si mesmo, siga as <a href=\"%2$s\">instrucións do desenvolvedor</a>."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-notes-3.6.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/notes/l10n/gl.js <==
OC.L10N.register(
    "notes",
    {
    "Reading notes from filesystem has failed." : "Produciuse un fallo na lectura de notas do sistema de ficheiros.",
    "Error" : "Erro",
    "New note" : "Nova nota",
    "Notes" : "Notas",
    "Distraction-free notes and writing" : "Escritura de notas sen distraccións ",
    "Please see Nextcloud server log for details." : "Vexa o rexistro do servidor do Nextcloud para obter máis detalles.",
    "Deleted {title}" : "{title} foi eliminado",
    "Deleted {number} notes" : "Eliminadas {number} notas",
    "Undo Delete" : "Desfacer a eliminación",
    "There are unsaved notes. Leaving the page will discard all changes!" : "Hai notas sen gardar. Saír da páxina desbotará todos os cambios!",
    "Settings" : "Axustes",
    "Folder to store your notes" : "Cartafol para almacenar as súas notas",
    "path to notes" : "ruta ás notas",
    "File extension for new notes" : "Extensión do ficheiro para notas novas",
    "All notes" : "Todas as notas",
    "Categories" : "Categorías",
    "No search result for “{search}” in {category}" : "Sen resultados de busca para «{search}» en {category}",
    "No search result for “{search}”" : "Sen resultados de busca para «{search}»",
    "Loading …" : "Cargando…",
    "Search result for “{search}” in {category}" : "Resultados de busca para «{search}» en {category}",
    "Search result for “{search}”" : "Resultados de busca para «{search}»",
    "Today" : "Hoxe",
    "Yesterday" : "Onte",
    "This week" : "Esta semana",
    "Last week" : "A semana pasada",
    "This month" : "Este mes",
    "Last month" : "O mes pasado",
    "Rename" : "Renomear",
    "Note's title" : "Título da nota",
    "Delete note" : "Eliminar nota",
    "Remove from favorites" : "Retirar de favoritos",
    "Add to favorites" : "Engadir a favoritos",
    "Error during preparing note for deletion." : "Produciuse un erro ao preparar a nota para a eliminación.",
    "Empty note" : "Nota baleira",
    "Write …" : "Escribir…",
    "Details" : "Detalles",
    "CTRL + /" : "CTRL + /",
    "Edit" : "Editar",
    "Preview" : "Vista previa",
    "Exit full screen" : "Saír da pantalla completa",
    "Full screen" : "Pantalla completa",
    "Save failed. Click to retry." : "Produciuse un fallo ao gardar. Prema para volver tentalo.",
    "Set category" : "Estabelecer a categoría",
    "Category" : "Categoría",
    "Uncategorized" : "Sen categorizar",
    "Click here to save manually" : "Prema aquí para gardar manualmente",
    "Saving failed!" : "Produciuse un fallo ao gardar!",
    "Last modified: {date}" : "Última modificación: {date}",
    "Note has unsaved changes" : "A nota contén cambios sen gardar",
    "Subcategory" : "Subcategoria",
    "_%n word_::_%n words_" : ["%n palabra","%n palabras"],
    "_%n character_::_%n characters_" : ["%n carácter","%n caracteres"],
    "Write down your thoughts without any distractions." : "Anote os seus pensamentos sen distraccións.",
    "Use Markdown markups to style your text." : "Empregue o marcado de Markdown para o estilo do seu texto.",
    "Organize your notes in categories." : "Organice as súas notas en categorías.",
    "Install the app for your mobile phone in order to access your notes from everywhere." : "Instale a aplicación para o seu teléfono móbil para poder acceder ás súas notas en calquera lugar.",
    "Android app" : "Apli de Android",
    "iOS app" : "Apli de iOS",
    "Start writing a note by clicking on “{newnote}” in the app navigation." : "Comece a escribir unha nota premendo en «{newnote}» na navegación da aplicación.",
    "You can create subcategories by using “/” as delimiter between parent category and subcategory, e.g. “{parent}/{sub}”." : "Pode crear subcategorías empregando «/» como delimitador entre a categoría principal e a subcategoría, por exemplo «{parent}/{sub}».",
    "Note not found." : "Non se atopou ningunha nota.",
    "Note is locked." : "A nota está bloqueada.",
    "Insufficient storage." : "Non ten espazo de almacenamento abondo.",
    "See JavaScript console and server log for details." : "Vexa a consola de JavaScript e o rexistro do servidor para os detalles.",
    "Updating settings has failed." : "Produciuse un fallo ao actualizar a configuración.",
    "Error from Nextcloud server: {msg}" : "Produciuse un erro no servidor do Nextcloud: {msg}",
    "Fetching notes has failed." : "Produciuse un fallo ao recuperar as notas.",
    "Fetching note {id} has failed." : "Produciuse un fallo ao recuperar a nota {id}.",
    "Refreshing note {id} has failed." : "Produciuse un fallo ao actualizar a nota {id}.",
    "Renaming note {id} has failed." : "Produciuse un fallo ao renomear a nota {id}.",
    "Creating new note has failed." : "Produciuse un fallo ao crear a nova nota.",
    "Saving note {id} has failed." : "Produciuse un fallo ao gardar a nota {id}.",
    "Updating title for note {id} has failed." : "Produciuse un fallo ao actualizar o titulo da nota {id}.",
    "Undo delete has failed for note {title}." : "Produciuse un fallo ao desfacer a eliminación da nota {title}.",
    "Deleting note {id} has failed." : "Produciuse un fallo ao eliminar a nota {id}.",
    "Toggling favorite for note {id} has failed." : "Produciuse un fallo ao activar o favorito para a nota {id}.",
    "Updating the note's category has failed. Is the target directory writable?" : "Produciuse un fallo ao actualizar a categoría da nota. Pódese escribir no directorio de destino?",
    "Updating the category for note {id} has failed." : "Produciuse un fallo ao actualizar a categoría da nota {id}.",
    "Development Mode" : "Modo desenvolvedor",
    "It looks that the notes app was installed from a development source. Please install it from the official <a href=\"%1$s\">Nextcloud App Store</a> instead. If you want to build the Notes app by yourself, please follow the <a href=\"%2$s\">developer instructions</a>." : "Parece que a aplicación de notas foi instalada dende unha orix de desenvolvemento. Instálea dende a <a href=\"%1$s\">tenda oficial de aplicacións do Nextcloud</a> no seu lugar. Se quere construír a aplicación Notes por si mesmo, siga as <a href=\"%2$s\">instrucións do desenvolvedor</a>."
},
"nplurals=2; plural=(n != 1);");
